@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011-2012 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine'; no warnings 'once';
 use rlib '../../../../..';
 
@@ -12,8 +12,14 @@ use Devel::Trepan::DB::LineCache;
 # Values inherited from parent
 use vars @Devel::Trepan::CmdProcessor::Command::Subcmd::SUBCMD_VARS;
 
-our $HELP = 'Set whether we use terminal highlighting';
+our $SHORT_HELP = 'Set whether we use terminal highlighting';
 our $MIN_ABBREV = length('hi');
+our $HELP = <<'HELP';
+=pod
+
+Set whether we use terminal highlighting.
+=cut
+HELP
 
 # sub complete($$) 
 # {
@@ -25,12 +31,12 @@ sub run($$)
 { 
     my ($self, $args) = @_;
     if (scalar @$args == 3 && 'reset' eq $args->[2]) {
-	DB::LineCache::clear_file_format_cache;
-	$self->{proc}{settings}{highlight} = 'term';
+        DB::LineCache::clear_file_format_cache;
+        $self->{proc}{settings}{highlight} = 'term';
     } else {
-	$self->SUPER::run($args);
-	$self->{proc}{settings}{highlight} = 'term' if 
-	    $self->{proc}{settings}{highlight};
+        $self->SUPER::run($args);
+        $self->{proc}{settings}{highlight} = 'term' if 
+            $self->{proc}{settings}{highlight};
     }
 }
 
