@@ -63,34 +63,12 @@ sub min($$) {
 sub current_source_text(;$)
 {
     my ($self, $opts) = @_;
-    $opts = {} unless defined $opts;
+    $opts = {max_continue => 5} unless defined $opts;
     my $filename    = $self->{frame}{file};
     my $line_number = $self->{frame}{line};
     my $text        = (DB::LineCache::getline($filename, $line_number, $opts)) 
         || '';
     chomp($text);
-    my $max_show_lines = $opts->{max_lines} || 4;
-    my $max_line = min($line_number + $max_show_lines - 1,
-                       DB::LineCache::size($filename));
-    my $raw_opts = {output => 'plain'};
-
-    # Accumulate lines if we think this line continues to the
-    # next. This code from newer perl5db is a bit heuristic, but
-    # overall it is probably helpful.
-    for ( my $i = $line_number + 1; 
-          $i <= $max_line && !DB::LineCache::is_trace_line($filename, $i); 
-          $i++ ) {
-        my $new_line = 
-            (DB::LineCache::getline($filename, $i, $opts))   || '';
-        my $raw_text = DB::LineCache::getline($filename, $i) || '';
-        
-        # Drop out on null statements, block closers, and comments.
-        # This could however still be wrong if we have these inside a
-        # string.  Also we might erroneously list function prototypes
-        # and headers, but this is probably harmless.
-        last if $raw_text =~ /^\s*([\;\}\#\n]|$)/;
-        $text .= ("\n" . $new_line);
-    }
     return $text;
 }
   
@@ -165,7 +143,10 @@ sub format_location($;$$$)
 sub print_location($;$)
 {
     my ($self,$opts) = @_;
-    $opts = {output => $self->{settings}{highlight}} unless defined $opts;
+    $opts = {
+        output => $self->{settings}{highlight},
+        max_continue => 5,
+    } unless defined $opts;
     my $loc  = $self->format_location;
     $self->msg(${loc});
 
